Package: ARPALData
Type: Package
Title: Retrieving and Analyzing Air Quality and Weather Data from ARPA
        Lombardia
Version: 2.0.1
Description: Contains functions for retrieving, managing, and analyzing air quality and weather data from the Regione Lombardia open database (<https://www.dati.lombardia.it/>).
    Data are collected by ARPA Lombardia (Lombardia Environmental Protection Agency), Italy, through its ground monitoring network (<https://www.dati.lombardia.it/stories/s/auv9-c2sj>).
    See the website <https://www.arpalombardia.it/> for further information on ARPA Lombardia's activities and history.
    Data quality (e.g., missing values, extreme values, and graphical mapping) has been checked in collaboration with members of ARPA Lombardia's air quality control office.
    The package provides observations since 1989 (for weather) and 1968 (for air quality), and these data are updated daily by the regional agency.
    A full description of the package is available in the companion paper Maranzano \& Algieri (2024), "ARPALData: an R package for retrieving and analyzing air quality
    and weather data from ARPA Lombardia (Italy)", Environmental and Ecological Statistics, <doi:10.1007/s10651-024-00599-6>.
License: GPL (>= 2)
Imports:
        tidyselect,dplyr,utils,rlang,lubridate,readr,stringr,tm,tidyr,eurostat,sf,ggplot2,tibble,aweek,curl,future,future.apply,httr2,jsonlite
Suggests: tidyverse, knitr, rmarkdown
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
Authors@R: 
    c(person(given = "Paolo",
             family = "Maranzano",
             role = c("aut", "cre", "cph"),
             email = "pmaranzano.ricercastatistica@gmail.com",
             comment = c(ORCID = "0000-0002-9228-2759")),
      person(given = "Andrea",
             family = "Algieri",
             role = c("aut", "cph"),
             email = "a.algieri@arpalombardia.it"))
NeedsCompilation: no
Packaged: 2026-07-16 21:07:03 UTC; paulm
Author: Paolo Maranzano [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-9228-2759>),
  Andrea Algieri [aut, cph]
Maintainer: Paolo Maranzano <pmaranzano.ricercastatistica@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-16 21:40:07 UTC
Built: R 4.5.2; ; 2026-07-16 22:42:38 UTC; unix
