export("get_ARPA_Lombardia_AQ_data","get_ARPA_Lombardia_W_data","get_ARPA_Lombardia_AQ_municipal_data",
       "get_ARPA_Lombardia_AQ_registry","get_ARPA_Lombardia_W_registry","get_ARPA_Lombardia_AQ_municipal_registry",
       "get_ARPA_Lombardia_zoning","get_Lombardia_geospatial",
       "is_ARPALdf", "is_ARPALdf_AQ", "is_ARPALdf_AQ_mun", "is_ARPALdf_W",
       "map_Lombardia_stations", "Time_aggregate","ARPALdf_Summary","ARPALdf_Summary_map",
       "registry_KNN_dist")
import("ggplot2")
importFrom("dplyr", "filter", "bind_rows", "case_when","recode","select")
importFrom("tidyselect", "where","contains","all_of","matches")
importFrom("utils", "data", "download.file","unzip")
importFrom("tidyr", "%>%")
importFrom("rlang", ".data", "check_installed","is_installed")
importFrom("lubridate", "ymd", "dmy_hms", "ymd_hms","interval","time_length","as_datetime","make_date","round_date","days_in_month","month","dmonths")
importFrom("stringr","str_to_title","str_replace_all","str_split","str_extract")
importFrom("readr", "read_csv","cols")
importFrom("eurostat", "get_eurostat_geospatial")
importFrom("sf", "st_as_sf")
importFrom("aweek","week2date","date2week")
importFrom("tibble","tibble","rownames_to_column")
importFrom("stats", "mad", "median", "sd","cor","lag","quantile")
importFrom("tm", "removePunctuation", "removeNumbers", "stripWhitespace")
importFrom("curl", "curl_fetch_disk","has_internet")
importFrom("future","plan","multisession","multicore","availableCores")
importFrom("future.apply","future_apply")

### Modified on 2026-06-15: import the new JSON/SODA download dependencies.
importFrom("httr2", "request", "req_url_query", "req_error", "req_headers", "req_perform", "resp_status", "resp_body_string")
importFrom("jsonlite", "fromJSON")
