#' ARPALData Package
#'
#' Contains functions for downloading and managing air quality and weather data from the Regione Lombardia open database.
#'     Data are collected by ARPA Lombardia (Lombardia Environmental Protection Agency), Italy.
#'
#' @docType package
#'
#' @author Paolo Maranzano \email{pmaranzano.ricercastatistica@gmail.com}
#'
#' @name ARPALData
NULL
